@@ -31,19 +31,21 @@ def Create_relvars():
 
 def Populate():
     """
-    Assign a value to each Flatland relvar. A value consists of a set of relations.
+    Assign a value to each Flatland relvar (table). A value consists of a set of relations.
     In Sqlalchemy terms, the tables are all updated with initial row data.
     """
-    # Iterate through the relvar dictionary to get each table
-    print("Populating Flatland DB...")
-    here = Path(__file__).parent / "Population"
-    pop_dirs = [
+    # We need to append each Population subirectory to our module search path
+    # because when we iterate through the file names in our relvar dictionary
+    # we don't know which file is in which subdirectory. So we can't just
+    # refer to each population module by the same path
+    here = Path(__file__).parent / "Population"  # Adjacent Population directory
+    pop_dirs = [  # Subdirectories organizing all population modules
         here / "Connector", here / "Decorator", here / "Drawing", here / "Node",
     ]
-    for d in pop_dirs:
-        print(f"Appending dir: {d}")
-        sys.path.append(str(d))
+    # Convert each Path object to a string and tack it on the end of our module search path
+    sys.path.extend([str(p) for p in pop_dirs])
 
+    # Iterate through the relvar dictionary to get each population and the table it goes into
     for instances, relvar in FlatlandDB.Relvars.items():
         # Set i to the initial population of row values (set of relation values)
         i = __import__(instances + '_instances')  # Each population filename ends with '_instances.py'
